summaryrefslogtreecommitdiff
path: root/TAO/tao/Transport.h
diff options
context:
space:
mode:
authoroci <oci@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2001-05-04 19:12:53 +0000
committeroci <oci@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2001-05-04 19:12:53 +0000
commit0bf7a00f5bba9d81fc7cedfbe9a2177a7e52a25c (patch)
tree114bb4ffff4644c69294e4425e4dc5560d8f5847 /TAO/tao/Transport.h
parent46a7821b08ff136d9068ef2aeb8fbbee9ac59936 (diff)
downloadATCD-0bf7a00f5bba9d81fc7cedfbe9a2177a7e52a25c.tar.gz
ChangeLogTag: Fri May 4 14:11:36 2001 Chad Elliott <elliott_c@ociweb.com>
Diffstat (limited to 'TAO/tao/Transport.h')
-rw-r--r--TAO/tao/Transport.h12
1 files changed, 9 insertions, 3 deletions
diff --git a/TAO/tao/Transport.h b/TAO/tao/Transport.h
index 04ec3c06c71..68f674088de 100644
--- a/TAO/tao/Transport.h
+++ b/TAO/tao/Transport.h
@@ -211,10 +211,16 @@ public:
/**
* Called by the cache when the cache is closing in order to fill
* in a handle_set in a lock-safe manner.
* @param handle_set the ACE_Handle_Set into which the transport
* should place any handle registered with the reactor
*/
- void provide_handle (ACE_Handle_Set &handle_set);
+ void provide_handle (ACE_Handle_Set &reactor_registered,
+ TAO_EventHandlerSet &unregistered);
/// Extracts the list of listen points from the <cdr> stream. The
/// list would have the protocol specific details of the
@@ -211,10 +211,16 @@ public:
* Called by the cache when the cache is closing in order to fill
* in a handle_set in a lock-safe manner.
- * @param handle_set the ACE_Handle_Set into which the transport
- * should place any handle registered with the reactor
+ *
+ * @param reactor_registered the ACE_Handle_Set into which the
+ * transport should place any handle registered with the reactor
+ *
+ * @param unregistered the TAO_EventHandlerSet into which the
+ * transport should place any event handler that is not registered
+ * with anyone
*/